@@ -321,11 +321,13 @@ sub start {
   if (my $file = $_[0]) {
     $file = File::Spec->catfile(lib => $file) unless $file =~ m!^.?lib!;
     $self->config({})->main_module_path($file);
-    my $work_dir = lc($self->project_name) =~ s!::!-!gr;
-    mkdir $work_dir;
-    chdir $work_dir or $self->abort("Could not chdir to $work_dir");
-    make_path dirname $self->main_module_path;
-    open my $MAINMODULE, '>>', $self->main_module_path or $self->abort("Could not create %s", $self->main_module_path);
+    unless (-e $file) {
+      my $work_dir = lc($self->project_name) =~ s!::!-!gr;
+      mkdir $work_dir;
+      chdir $work_dir or $self->abort("Could not chdir to $work_dir");
+      make_path dirname $self->main_module_path;
+      open my $MAINMODULE, '>>', $self->main_module_path or $self->abort("Could not create %s", $self->main_module_path);
+    }
   }
 
   symlink $self->main_module_path, 'README.pod' unless -e 'README.pod';
@@ -335,8 +337,8 @@ sub start {
   $self->render('Changes') if $changelog eq 'Changes';
   $self->render('MANIFEST.SKIP');
   $self->render('t/00-basic.t');
-  $self->system(qw( git add cpanfile MANIFEST.SKIP t ), $changelog);
-  $self->system(qw( git commit --amend -C HEAD )) if @_;
+  $self->system(qw(git add cpanfile MANIFEST.SKIP t), $changelog);
+  $self->system(qw(git commit --amend -C HEAD --allow-empty)) if @_;
   $self;
 }
 
@@ -509,7 +511,7 @@ sub _update_changes {
   my $changes;
 
   unless (eval "require CPAN::Changes; 1") {
-    say "# Channge update ./Changes without CPAN::Changes" unless $self->silent;
+    say "# Cannot update './Changes' without CPAN::Changes. Install using cpanm CPAN::Changes" unless $self->silent;
     return;
   }
 
@@ -596,7 +598,7 @@ WriteMakefile(
   },
   BUILD_REQUIRES => <%= $_[1]->{BUILD_REQUIRES} %>,
   PREREQ_PM => <%= $_[1]->{PREREQ_PM} %>,
-  test => { TESTS => 't/*.t' },
+  test => {TESTS => (-e 'META.yml' ? 't/*.t' : 't/*.t xt/*.t')},
 );
 @@ MANIFEST.SKIP
 <%= $_[0]->_include_mskip_file %>
