@@ -24,7 +24,7 @@ sub goto_workdir {
   my ($class, $workdir, $create) = @_;
   my $base = 'workdir';
 
-  plan skip_all => "Cannot test on $^O" unless grep { $^O eq $_ } qw(linux darwin);
+  plan skip_all => "Cannot test on $^O" if $^O eq 'MSWin32';
   $class->mock_git unless $ENV{GIT_REAL_BIN};
   $class->test_git($ENV{GIT_REAL_BIN});
   $create //= 1;
@@ -84,9 +84,13 @@ sub test_git {
 
   plan skip_all => "Invalid git: $git" unless $git =~ qr{^[\w\/-]+$};
   $output = qx{$git --version 2>/dev/null};
+  $output =~ s![\n\r]!!g;
   plan skip_all => "Invalid git: $output" unless $output =~ qr{\b\s+version\s+\d};
   plan skip_all => "Unsupported git version: $output" if $output =~ qr{\s1\.4};
   diag "git --version: $output" unless $output =~ /\b(1\.9|2\.[0123])/;
+  $output = qx{git config --global --get-regexp user.* 2>/dev/null};
+  $output =~ s![\n\r]!!g;
+  plan skip_all => "Cannot run with unknown git user: $output" unless $output =~ /user\.email/ and $output =~ /user\.name/;
 }
 
 sub import {
